@@ -51,15 +51,14 @@ below you can find a usage example::
 
     with iio.imopen("test.mp4", "w", plugin="pyav") as file:
         file.init_video_stream("libx264")
-        file.container_metadata["comment"] = "This video has a rotation flag."
-        file.video_stream_metadata["rotate"] = "90"
+        file.container_metadata["comment"] = "This video was created using ImageIO."
 
         for _ in range(5):
             for frame in iio.imiter("imageio:newtonscradle.gif"):
                 file.write_frame(frame)
 
     meta = iio.immeta("test.mp4", plugin="pyav")
-    assert meta["comment"] == "This video has a rotation flag."
+    assert meta["comment"] == "This video was created using ImageIO."
 
 
 
@@ -179,7 +178,6 @@ examples to better understand how to use them.
 from fractions import Fraction
 from math import ceil
 from typing import Any, Dict, List, Optional, Tuple, Union, Generator
-import warnings
 
 import av
 import av.filter
@@ -270,15 +268,15 @@ class PyAVPlugin(PluginV3):
         standard interface to access various the various ImageResources and
         serves them to the plugin as a file object (or file). Check the docs for
         details.
+    container : str
+        Only used during `iio_mode="w"`! If not None, overwrite the default container
+        format chosen by pyav.
+    kwargs : Any
+        Additional kwargs are forwarded to PyAV's constructor.
 
     """
 
-    def __init__(
-        self,
-        request: Request,
-        *,
-        container: str = None,
-    ) -> None:
+    def __init__(self, request: Request, *, container: str = None, **kwargs) -> None:
         """Initialize a new Plugin Instance.
 
         See Plugin's docstring for detailed documentation.
@@ -305,9 +303,9 @@ class PyAVPlugin(PluginV3):
                     # HTTP-based streams like DASH. Note that solving streams
                     # like this is temporary until the new request object gets
                     # implemented.
-                    self._container = av.open(request.raw_uri)
+                    self._container = av.open(request.raw_uri, **kwargs)
                 else:
-                    self._container = av.open(request.get_file())
+                    self._container = av.open(request.get_file(), **kwargs)
                 self._video_stream = self._container.streams.video[0]
                 self._decoder = self._container.decode(video=0)
             except av.AVError:
@@ -332,7 +330,9 @@ class PyAVPlugin(PluginV3):
                 pass  # read-only, nothing we can do
 
             try:
-                self._container = av.open(file_handle, mode="w", format=container)
+                self._container = av.open(
+                    file_handle, mode="w", format=container, **kwargs
+                )
             except ValueError:
                 raise InitializationError(
                     f"PyAV can not write to `{self.request.raw_uri}`"
@@ -726,14 +726,6 @@ class PyAVPlugin(PluginV3):
 
         """
 
-        av_version = tuple(int(x) for x in av.__version__.split("."))
-        if av_version == (10, 0, 0):
-            warnings.warn(
-                "PyAV 10.0.0 has known issues reading metadata."
-                " If you need video metadata consider using v9.2.0 instead.",
-                UserWarning,
-            )
-
         metadata = dict()
 
         if index is ...:
@@ -788,8 +780,15 @@ class PyAVPlugin(PluginV3):
         if is_write and self._video_stream is not None:
             self._flush_writer()
 
+        if self._video_stream is not None:
+            try:
+                self._video_stream.close()
+            except ValueError:
+                pass  # stream already closed
+
         if self._container is not None:
             self._container.close()
+
         self.request.finish()
 
     def __enter__(self) -> "PyAVPlugin":
@@ -816,7 +815,7 @@ class PyAVPlugin(PluginV3):
         Parameters
         ----------
         codec : str
-            The codec to use, e.g. ``"x264"`` or ``"vp9"``.
+            The codec to use, e.g. ``"libx264"`` or ``"vp9"``.
         fps : float
             The desired framerate of the video stream (frames per second).
         pixel_format : str
